@@ -41,11 +41,17 @@
 #include "util/htmlmarshal.h"
 #include "htmlevent.h"
 #include "htmlview.h"
+#include "config.h"
+
+#ifdef ENABLE_ACCESSIBILITY
+#include "layout/htmlboxtable.h"
 #include "a11y/htmlviewaccessiblefactory.h"
 #include "a11y/htmlboxaccessiblefactory.h"
 #include "a11y/htmlboxblockaccessiblefactory.h"
 #include "a11y/htmlboxembeddedaccessiblefactory.h"
+#include "a11y/htmlboxtableaccessiblefactory.h"
 #include "a11y/htmlboxtextaccessiblefactory.h"
+#endif
 
 enum {
 	MOVE_CURSOR,
@@ -63,7 +69,9 @@ static GtkLayoutClass *parent_class = NULL;
 static gboolean html_view_remove_layout_box (HtmlView *view, DomNode *node);
 static void html_view_try_jump (HtmlView *view);
 
+#ifdef ENABLE_ACCESSIBILITY
 static AtkObject *  html_view_get_accessible (GtkWidget *widget);
+#endif
 
 typedef enum {
 	HTML_VIEW_SCROLL_TO_TOP,
@@ -130,7 +138,6 @@ html_view_scroll_to_node (HtmlView *view, DomNode *node, HtmlViewScrollToType ty
 	
 	if (adj->value < y || adj->value + adj->page_size > y) 
 #endif
-	g_print ("Going to scroll to node: %p %s, %d\n", box, G_OBJECT_TYPE_NAME (box), html_box_get_absolute_y (box));
 }
 
 static void
@@ -166,7 +173,6 @@ html_view_set_adjustments (HtmlView *view)
 static void
 html_view_relayout (HtmlView *view)
 {
-	g_print ("View relayout!! %d, %d\n", GTK_WIDGET (view)->allocation.width, GTK_WIDGET (view)->allocation.height);
 	/* Tell the root layout box to relayout itself */
 	if (view->painter && view->root) {
 		HtmlRelayout *relayout;
@@ -215,7 +221,6 @@ relayout_timeout_callback (gpointer data)
 {
 	HtmlView *view = HTML_VIEW (data);
 
-	g_print ("in timeout relayout callback!\n");
         html_view_relayout (view);
 	
 	view->relayout_timeout_id = 0;
@@ -233,7 +238,6 @@ relayout_idle_callback (gpointer data)
 {
         HtmlView *view = HTML_VIEW (data);
 
-	g_print ("in idle relayout callback!\n");
         html_view_relayout (view);
 
 	view->relayout_idle_id = 0;
@@ -388,8 +392,6 @@ html_view_removed (HtmlDocument *document, DomNode *node, HtmlView *view)
 {
 	HtmlBox *box = html_view_find_layout_box (view, node, FALSE);
 
-	g_print ("Removing: %s\n", node->xmlnode->name);
-	
 	/* Mark the boxes that need to be relayouted */
 	if (box && box->parent)
 		html_box_set_unrelayouted_up (box->parent);		
@@ -674,8 +676,6 @@ html_view_button_press (GtkWidget *widget, GdkEventButton *event)
 static gboolean
 html_view_button_release (GtkWidget *widget, GdkEventButton *event)
 {
-	g_print ("whee, button release!\n");
-
 	if (event->window != GTK_LAYOUT (widget)->bin_window)
 		return FALSE;
 
@@ -834,7 +834,6 @@ html_view_real_move_cursor (HtmlView *html_view, GtkMovementStep step, gint coun
 	default:
 		g_warning ("unknown step!\n");
 	}
-	g_print ("Moving cursor!\n");
 }
 
 static void
@@ -1008,7 +1007,9 @@ html_view_class_init (HtmlViewClass *klass)
 	widget_class->enter_notify_event = html_view_enter_notify;
 	widget_class->leave_notify_event = html_view_leave_notify;
 
+#ifdef ENABLE_ACCESSIBILITY
 	widget_class->get_accessible = html_view_get_accessible;
+#endif
 
 	container_class->set_focus_child = html_view_set_focus_child;
 	
@@ -1136,10 +1137,13 @@ html_view_new (void)
 	return GTK_WIDGET (view);
 }
 
+
+#ifdef ENABLE_ACCESSIBILITY
+
 static AtkObject *
 html_view_get_accessible (GtkWidget *widget)
 {
-        gboolean first_time = TRUE;
+        static gboolean first_time = TRUE;
 
 	if (first_time) {
 		AtkObjectFactory *factory;
@@ -1175,6 +1179,9 @@ html_view_get_accessible (GtkWidget *widget)
 			atk_registry_set_factory_type (registry,
 						       HTML_TYPE_BOX,
 						       HTML_TYPE_BOX_ACCESSIBLE_FACTORY);
+			atk_registry_set_factory_type (registry,
+						       HTML_TYPE_BOX_TABLE,
+						       HTML_TYPE_BOX_TABLE_ACCESSIBLE_FACTORY);
 			atk_registry_set_factory_type (registry,
 						       HTML_TYPE_BOX_TEXT,
 						       HTML_TYPE_BOX_TEXT_ACCESSIBLE_FACTORY);
@@ -1183,3 +1190,5 @@ html_view_get_accessible (GtkWidget *widget)
 	}
 	return GTK_WIDGET_CLASS (parent_class)->get_accessible (widget);
 }
+
+#endif /* ENABLE_ACCESSIBILITY */
